@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2011 Filipe Saraiva <filipe@kde.org>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2011 Filipe Saraiva <filipe@kde.org>
+*/
 
 #include "scilabcompletionobject.h"
 
@@ -43,7 +28,7 @@ void ScilabCompletionObject::fetchCompletions()
 
     setCompletions(allCompletions);
 
-    emit fetchingDone();
+    Q_EMIT fetchingDone();
 }
 
 void ScilabCompletionObject::fetchIdentifierType()
@@ -53,12 +38,12 @@ void ScilabCompletionObject::fetchIdentifierType()
 
     if (std::binary_search(ScilabKeywords::instance()->functions().begin(), ScilabKeywords::instance()->functions().end(),
             identifier()))
-        emit fetchingTypeDone(FunctionType);
+        Q_EMIT fetchingTypeDone(FunctionType);
     else if (std::binary_search(ScilabKeywords::instance()->keywords().begin(),ScilabKeywords::instance()->keywords().end(),
             identifier()))
-        emit fetchingTypeDone(KeywordType);
+        Q_EMIT fetchingTypeDone(KeywordType);
     else
-        emit fetchingTypeDone(VariableType);
+        Q_EMIT fetchingTypeDone(VariableType);
 }
 
 bool ScilabCompletionObject::mayIdentifierContain(QChar c) const
