@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 Martin Kuettler <martin.kuettler@gmail.com>
+*/
 
 #ifndef IMAGEENTRY_H
 #define IMAGEENTRY_H
@@ -30,6 +15,7 @@ class Worksheet;
 class ActionBar;
 class WorksheetImageItem;
 class QFileSystemWatcher;
+class QGraphicsSceneMouseEvent;
 
 class ImageEntry : public WorksheetEntry
 {
@@ -53,8 +39,6 @@ class ImageEntry : public WorksheetEntry
 
     QSizeF imageSize(const ImageSize& imgSize);
 
-    void interruptEvaluation() override;
-
     void layOutForWidth(qreal entry_zone_x, qreal w, bool force = false) override;
 
   public Q_SLOTS:
@@ -74,6 +58,8 @@ class ImageEntry : public WorksheetEntry
     QString latexSizeString(const ImageSize& imgSize);
     void addActionsToBar(ActionBar* actionBar) override;
 
+    void mouseDoubleClickEvent(QGraphicsSceneMouseEvent*) override;
+
   private:
     QString m_imagePath;
     QString m_fileName;
